@@ -1,6 +1,4 @@
-import json
 import uuid
-import base64
 from .agent_config import AgentConfig
 from .agent_signature import AgentSignature
 from .types import AgentMessageType
